import argparse
import logging
import os
import sys

from carom import client


logging.basicConfig(filename='/var/log/carom-client.log', level=logging.INFO)
log = logging.getLogger(__name__)


def main(args=None):
    if args is None:
        args = sys.argv[1:]
    parser = argparse.ArgumentParser()
    parser.add_argument("-c", metavar="CONFIG", default="/boot/carom-client.conf",
                        help="Config file (/boot/carom-client.conf)")
    parser.add_argument("-v", action="store_true", help="Verbose output")
    parser.add_argument("-u", "--uuid", action="store_true", help="get uuid from node")
    parser.add_argument("-d", "--direct", action="store_true", help="force direct http call against of worker usage")
    parser.add_argument("-s", "--status", action="store_true", help="Print out gpio status of inputs")
    args = parser.parse_args()
    if args.uuid:
        print(client.CaromClient.get_uuid())
        sys.exit(0)
    cc = client.CaromClient(args)
    if args.status:
        print(cc.get_gpio_status())
        sys.exit(0)
    if not os.access(args.c, os.R_OK):
        log.info('Configfile not found or is not readable!')
        print('Configfile not found or is not readable!')
        sys.exit(1)
    cc.start()


if __name__ == "__main__":
    main()
